import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: 路由配置项
 *
 * hidden: true                     // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true                 // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                  // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                  // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                  // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect             // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'               // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * query: '{"id": 1, "name": "ry"}' // 访问路由的默认传递参数
 * roles: ['admin', 'common']       // 访问路由的角色权限
 * permissions: ['a:a:a', 'b:b:b']  // 访问路由的菜单权限
 * meta : {
    noCache: true                   // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'                  // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'                // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false               // 如果设置为false，则不会在breadcrumb面包屑中显示
    activeMenu: '/system/user'      // 当路由设置了该属性，则会高亮相对应的侧边栏。
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/redirect')
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login'),
    hidden: true
  },
  {
    path: '/register',
    component: () => import('@/views/register'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error/401'),
    hidden: true
  },
  // 隐私政策
  {
    path: '/privacy-policy',
    component: () => import('@/views/document-management/privacy-policy/privacy-policy'),
    hidden: true
  },
  // 文档管理
  {
    path: '/document-management',
    component: Layout,
    hidden: true,
    permissions: ['*:*:*'],
    children: [
      {
        path: 'privacy-policy',
        props: true,
        component: () => import('@/views/document-management/privacy-policy/privacy-policy'),
        name: 'privacy-policy',
        meta: { title: '隐私政策', icon: 'date' }
      },
      {
        path: 'user-protocol',
        props: true,
        component: () => import('@/views/document-management/user-protocol/user-protocol'),
        name: 'user-protocol',
        meta: { title: '用户协议', icon: 'table' }
      },
      {
        path: 'about-us',
        props: true,
        component: () => import('@/views/document-management/about-us/about-us.vue'),
        name: 'about-us',
        meta: { title: '关于我们', icon: 'github' }
      },
      {
        path: 'entry-contract',
        props: true,
        component: () => import('@/views/document-management/entry-contract/entry-contract'),
        name: 'entry-contract',
        meta: { title: '合同文件', icon: 'component' }
      }
    ]
  },
  // 设备
  {
    path: '/equipment-management',
    component: Layout,
    hidden: true,
    permissions: ['*:*:*'],
    children: [
      {
        path: 'equipment-management',
        props: true,
        component: () => import('@/views/equipment-management/equipment-management/equipment-management'),
        name: 'EquipmentManagement',
        meta: { title: '设备管理', icon: 'date' }

      },
      {
        path: 'equipment-detail/:id/:identify',
        props: true,
        component: () => import('@/views/equipment-management/equipment-management/equipment-detail'),
        name: 'EquipmentDetail',
        meta: { title: '设备详情' }
      },
      {
        path: 'equipment-add',
        props: true,
        component: () => import('@/views/equipment-management/equipment-management/equipment-add'),
        name: 'EquipmentAdd',
        meta: { title: '设备新增' }
      },
      {
        path: 'equipment-check',
        props: true,
        component: () => import('@/views/equipment-management/equipment-management/equipment-check'),
        name: 'EquipmentCheck',
        meta: { title: '检查项目' }
      },

      {
        path: 'use-management',
        props: true,
        component: () => import('@/views/equipment-management/use-management/use-management'),
        name: 'UseManagement',
        meta: { title: '使用管理', icon: 'table' }
      },
      {
        path: 'use-details',
        props: true,
        component: () => import('@/views/equipment-management/use-management/use-details'),
        name: 'UseDetails',
        meta: { title: '详情', icon: 'table' }
      }
    ]
  },
  // 病历管理
  {
    path: '/medical-record-management',
    component: Layout,
    hidden: true,
    permissions: ['*:*:*'],
    children: [
      {
        path: 'index',
        props: true,
        component: () => import('@/views/medical-record-management/medical-record-management'),
        name: 'MedicalRecordManagement',
        meta: { title: '病历管理', icon: 'component' }
      },
      // 病历详情
      {
        path: 'medical-detail/:id',
        component: () => import('@/views/medical-record-management/medical-edit'),
        name: 'MedicalDetail',
        props: true,
        meta: {
          title: '病历详情', icon: 'component'
        }
      },
      // 病历编辑
      {
        path: 'medical-edit/:id',
        component: () => import('@/views/medical-record-management/medical-edit'),
        name: 'MedicalEdit',
        props: true,
        meta: {
          title: '病历编辑', icon: 'component'
        }
      }
    ]
  },
  // 个人中心
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'profile',
        component: () => import('@/views/system/user/profile/index'),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user' }
      }
    ]
  },
  // 文章
  {
    path: '/article/management',
    component: Layout,
    hidden: true,
    permissions: ['*:*:*'],
    children: [
      {
        path: 'index',
        props: true,
        component: () => import('@/views/article-management/article-management'),
        name: 'Article-management',
        meta: { title: '文章管理', icon: 'component' }
      },
      // 文章编辑路由
      {
        path: 'article-edit/:id',
        props: true,
        component: () => import('@/views/article-management/article-edit'),
        name: 'Article-edit',
        meta: { title: '文章编辑', icon: 'component' }
      },
      // 文章详情路由
      {
        path: 'article-detail/:id',
        component: () => import('@/views/article-management/article-detail'),
        name: 'ArticleDetail',
        props: true,
        meta: {
          title: '文章详情', icon: 'component'
        }
      },
      // 文章添加路由
      {
        path: 'article-insert',
        component: () => import('@/views/article-management/article-insert'),
        name: 'ArticleInsert',
        props: true,
        meta: {
          title: '新增文章',
          activeMenu: '/article-management'
        }
      }
    ]
  },
  // 轮播
  {
    path: '/banner-management',
    component: Layout,
    hidden: true,
    permissions: ['*:*:*'],
    children: [
      // 轮播管理
      {
        path: 'index',
        props: true,
        component: () => import('@/views/banner_management/banner_management'),
        name: 'BannerManagement',
        meta: { title: '轮播管理', icon: 'component' }
      },
      // 轮播添加路由
      {
        path: 'banner-add',
        component: () => import('@/views/banner_management/banner_add.vue'),
        name: 'BannerInsert',
        props: true,
        meta: {
          title: '新增轮播',
          icon: 'component'
        }
      },
      // 轮播编辑路由
      {
        path: 'banner-edit',
        component: () => import('@/views/banner_management/banner_edit.vue'),
        name: 'BannerEdit',
        props: true,
        meta: {
          title: '编辑轮播',
          icon: 'component'
        }
      },
      // 轮播详情路由
      {
        path: 'banner-detail',
        component: () => import('@/views/banner_management/banner_detail.vue'),
        name: 'BannerDetail',
        props: true,
        meta: {
          title: '轮播详情',
          icon: 'component'
        }
      }
    ]
  },
  // 业务管理
  {
    path: '/service-management',
    component: Layout,
    hidden: true,
    permissions: ['*:*:*'],
    children: [
      // 挂号管理
      {
        path: 'registration-queue',
        props: true,
        component: () => import('@/views/service-management/registration-queue/registration-queue'),
        name: 'RegistrationQueue',
        meta: {
          title: '挂号管理', icon: 'component'
        }
      },
      // 挂号详情路由
      {
        path: 'registration-detail/:id/:type',
        component: () => import('@/views/service-management/registration-queue/registration-detail'),
        name: 'RegistrationDetail',
        props: true,
        meta: {
          title: '挂号详情', icon: 'component'
        }
      },
      // 挂号新增路由
      {
        path: 'registration-add',
        component: () => import('@/views/service-management/registration-queue/registration-add'),
        name: 'RegistrationAdd',
        props: true,
        meta: {
          title: '挂号新增', icon: 'component'
        }
      },
      // 治疗管理
      {
        path: 'treatment-management',
        component: () => import('@/views/service-management/treatment-management/treatment-management'),
        name: 'TreatmentManagement',
        props: true,
        meta: {
          title: '治疗管理', icon: 'component'
        }
      },
      // 检查管理
      {
        path: 'medical-record-management',
        component: () => import('@/views/service-management/medical-record-management/medical-record-management.vue'),
        name: 'CheckManagement',
        props: true,
        meta: {
          title: '检查管理', icon: 'component'
        }
      },
      // 检查详情
      {
        path: 'check-detail',
        props: true,
        hidden: true,
        component: () => import('@/views/service-management/medical-record-management/check-detail.vue'),
        name: 'CheckDetail',
        meta: {
          title: '检查详情',
          icon: 'component'
        }
      },
      // 检查管理-立即预约
      {
        path: 'check-subscribe',
        props: true,
        hidden: true,
        component: () => import('@/views/service-management/medical-record-management/check-subscribe.vue'),
        name: 'CheckSubscribe',
        meta: {
          title: '立即预约',
          icon: 'component'
        }
      },
      // 检查管理-檢查項目
      {
        path: 'check-item',
        props: true,
        hidden: true,
        component: () => import('@/views/service-management/medical-record-management/check-item.vue'),
        name: 'CheckItem',
        meta: {
          title: '检查项目',
          icon: 'component'
        }
      },
      // 治疗详情
      {
        path: 'treatment-detail',
        props: true,
        hidden: true,
        component: () => import('@/views/service-management/treatment-management/treatment-detail'),
        name: 'TreatmentDetail',
        meta: {
          title: '治疗详情',
          icon: 'component'
        }
      },
      // 治疗管理-立即预约
      {
        path: 'treatment-subscribe',
        props: true,
        hidden: true,
        component: () => import('@/views/service-management/treatment-management/treatment-subscribe'),
        name: 'TreatmentSubscribe',
        meta: {
          title: '立即预约',
          icon: 'component'
        }
      },
      // 治疗管理-治疗項目
      {
        path: 'treatment-item',
        props: true,
        hidden: true,
        component: () => import('@/views/service-management/treatment-management/treatment-item'),
        name: 'TreatmentItem',
        meta: {
          title: '治疗项目',
          icon: 'component'
        }
      }
    ]
  }
]

// 动态路由，基于用户权限动态去加载
export const dynamicRoutes = [
  {
    path: '/system/user-auth',
    component: Layout,
    hidden: true,
    permissions: ['system:user:edit'],
    children: [
      {
        path: 'role/:userId(\\d+)',
        component: () => import('@/views/system/user/authRole'),
        name: 'AuthRole',
        meta: { title: '分配角色', activeMenu: '/system/user' }
      }
    ]
  },
  {
    path: '/system/role-auth',
    component: Layout,
    hidden: true,
    permissions: ['system:role:edit'],
    children: [
      {
        path: 'user/:roleId(\\d+)',
        component: () => import('@/views/system/role/authUser'),
        name: 'AuthUser',
        meta: { title: '分配用户', activeMenu: '/system/role' }
      }
    ]
  },
  // 数据字典
  {
    path: '/system/dict-data',
    component: Layout,
    hidden: true,
    permissions: ['system:dict:list'],
    children: [
      {
        path: 'index/:dictId(\\d+)',
        component: () => import('@/views/system/dict/data'),
        name: 'Data',
        meta: { title: '字典数据', activeMenu: '/system/dict' }
      }
    ]
  },
  {
    path: '/monitor/job-log',
    component: Layout,
    hidden: true,
    permissions: ['monitor:job:list'],
    children: [
      {
        path: 'index/:jobId(\\d+)',
        component: () => import('@/views/monitor/job/log'),
        name: 'JobLog',
        meta: { title: '调度日志', activeMenu: '/monitor/job' }
      }
    ]
  },
  {
    path: '/tool/gen-edit',
    component: Layout,
    hidden: true,
    permissions: ['tool:gen:edit'],
    children: [
      {
        path: 'index/:tableId(\\d+)',
        component: () => import('@/views/tool/gen/editTable'),
        name: 'GenEdit',
        meta: { title: '修改生成配置', activeMenu: '/tool/gen' }
      }
    ]
  }

]

// 防止连续点击多次路由报错
const routerPush = Router.prototype.push
Router.prototype.push = function push(location) {
  return routerPush.call(this, location).catch(err => err)
}

export default new Router({
  base: window.__POWERED_BY_QIANKUN__ ? '/pet-business-web/' : '/',
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
